@@ -14,7 +14,7 @@ use MIME::Base64;
 use Carp;
 
 use version;
-our $VERSION = qv('0.07');
+our $VERSION = qv('0.08');
 
 our @ISA=qw(DMTF::CIM);
 
@@ -617,17 +617,25 @@ sub current_uri
 	if($self->{CURRENTURI}->path =~ /^(?:\/([^:]*?))?(?::.*)?$/) {
 		$cnamespace=$1;
 	}
-	my ($namespace, $instance);
+	my ($namespace, $instance, $path);
 	if(defined $newuri->path) {
-		if($newuri->path =~ /^\/([^:]*)$/) {	# Starts with a slash, has no colon
+		if(ref($newuri) eq 'URI::_generic') {
+			$path=$newuri;
+		}
+		else {
+			$path=$newuri->path;
+		}
+	}
+	if(defined $path) {
+		if($path =~ /^\/([^:]*)$/) {	# Starts with a slash, has no colon
 			# no class
 			$namespace=$1;
 		}
-		elsif($newuri->path =~ /^([^\/].*)$/) { # Doesn't start with a slash
+		elsif($path =~ /^([^\/].*)$/) { # Doesn't start with a slash
 			# no namespace
 			$instance=$1;
 		}
-		elsif($newuri->path =~ /^\/([^:]*):(.*)$/) { # Starts with a slash, has colon
+		elsif($path =~ /^\/([^:]*):(.*)$/) { # Starts with a slash, has colon
 			($namespace, $instance)=($1,$2);
 		}
 		else {
@@ -838,6 +846,7 @@ sub _get_instances
 			return;
 		}
 		if(!defined $items) {
+			next if($response->local_name eq 'EnumerateResponse');	# The EnumerateResponse may not have an Items in it.
 			return ();
 		}
 		for(my $item=$items->first_child;defined $item;$item=$item->next_sibling) {
@@ -1434,7 +1443,7 @@ DMTF::CIM::WSMan - Provides WSMan CIM binding
 
 =head1 VERSION
 
-This document describes DMTF::CIM::WSMan version 0.07
+This document describes DMTF::CIM::WSMan version 0.08
 
 
 =head1 SYNOPSIS
